Method: SwaggerClient::SiteApi#site_get_activation_code_with_http_info

Defined in:
lib/swagger_client/api/site_api.rb

#site_get_activation_code_with_http_info(version, opts = {}) ⇒ Array<(GetActivationCodeResponse, Fixnum, Hash)>

Get an activation code for a site. Before you can use this endpoint, MINDBODY must approve your developer account for live access. If you have finished testing in the sandbox and are ready to begin working with MINDBODY customers, log into your account and request to go live. See [Accessing Business Data From MINDBODY](developers.mindbodyonline.com/PublicDocumentation/V6#accessing-business-data) for more information about the activation code and how to use it. Once you are approved, this endpoint returns an activation code.This endpoint supports only one site per call.

Parameters:

  • version
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :authorization (String)

    A staff user authorization token.

Returns:

  • (Array<(GetActivationCodeResponse, Fixnum, Hash)>)

    GetActivationCodeResponse data, response status code and response headers



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/swagger_client/api/site_api.rb', line 39

def site_get_activation_code_with_http_info(version, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SiteApi.site_get_activation_code ...'
  end
  # verify the required parameter 'version' is set
  if @api_client.config.client_side_validation && version.nil?
    fail ArgumentError, "Missing the required parameter 'version' when calling SiteApi.site_get_activation_code"
  end
  # resource path
  local_var_path = '/public/v{version}/site/activationcode'.sub('{' + 'version' + '}', version.to_s)

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/json', 'application/xml', 'text/xml', 'multipart/form-data'])
  header_params[:'authorization'] = opts[:'authorization'] if !opts[:'authorization'].nil?

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'GetActivationCodeResponse')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SiteApi#site_get_activation_code\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end